@@ -88,7 +88,9 @@ def get_docker_compose_cmd(path):
             "Warning: Could not find a 'docker-compose.yml' file."
         )
 
-    docker_compose_base = ["docker-compose", "-f", docker_compose_filename]
+    conf = config.Config()
+    cmd = conf.config.get("docker-compose", ["docker-compose"])
+    docker_compose_base = cmd + ["-f", docker_compose_filename]
 
     def docker_compose(*commands):
         return docker_compose_base + [cmd for cmd in commands]
@@ -174,24 +176,35 @@ def get_db_container_id(path, raise_on_missing=True, prefix="DEFAULT"):
         raise exceptions.DivioException(
             "docker-compose.yml not found. Unable to find database container"
         )
+    should_check_oldstyle = False
+    output = None
+
     try:
         output = check_output(
             docker_compose("ps", "-q", "database_{}".format(prefix).lower()),
             catch=False,
             stderr=open(os.devnull, "w"),
         ).rstrip(os.linesep)
-        if not output and raise_on_missing:
-            raise exceptions.DivioException(
-                "Unable to find database container"
-            )
+        if not output:
+            # This behavior was briefly used in docker-compose v2.
+            # The output can be empty if the container does not exist.
+            # For information: https://github.com/docker/compose-cli/issues/1893
+            should_check_oldstyle = True
     except subprocess.CalledProcessError:
-        output = check_output(docker_compose("ps", "-q", "db")).rstrip(
-            os.linesep
-        )
-        if not output and raise_on_missing:
-            raise exceptions.DivioException(
-                "Unable to find database container"
+        # A not existing service will result in an error.
+        should_check_oldstyle = True
+
+    if should_check_oldstyle:
+        try:
+            output = check_output(docker_compose("ps", "-q", "db")).rstrip(
+                os.linesep
             )
+        except subprocess.CalledProcessError:
+            # A not existing service will result in an error.
+            pass
+
+    if not output and raise_on_missing:
+        raise exceptions.DivioException("Unable to find database container")
     return output
 
 
